@@ -33,7 +33,7 @@
 #include "gsm-presence.h"
 #include "gsm-presence-glue.h"
 
-#define GSM_PRESENCE_DBUS_PATH "/org/mate/SessionManager/Presence"
+#define GSM_PRESENCE_DBUS_PATH "/org/gnome/SessionManager/Presence"
 
 #define GS_NAME      "org.mate.ScreenSaver"
 #define GS_PATH      "/org/mate/ScreenSaver"
@@ -41,8 +41,6 @@
 
 #define MAX_STATUS_TEXT 140
 
-#define IS_STRING_EMPTY(x) ((x)==NULL||(x)[0]=='\0')
-
 #define GSM_PRESENCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_PRESENCE, GsmPresencePrivate))
 
 struct GsmPresencePrivate
